| Package: |
| Roleswitch |
| Type: |
| Package |
| Version: |
| 1.5.2 |
| Date: |
| 2013-12-20 |
| License: |
| GPL-2 |
roleswitch takes as inputs the mRNA and miRNA expression as numerical vector and seedmatch (integer) matrix provided by the user or generated from getSeedMatrix. The function then outputs a list with p.xz containing the ProMISe as the final results and other results for diagnostic purpose.
Arvey, A., Larsson, E., Sander, C., Leslie, C. S., & Marks, D. S. (2010). Target mRNA abundance dilutes microRNA and siRNA activity. Molecular systems biology, 6, 1-7. doi:10.1038/msb.2010.24
roleswitch
library(Roleswitch)
ls("package:Roleswitch")
Run the code above in your browser using DataLab