roleswitch(x.o, z.o, c, maxiter = 200, tol = 1e-05, eta.z = 0.001, expected.total = 1.3, verbose = TRUE, annotation.db, probe2genesymbol=TRUE, ...)x.o is an eSet or ExpressionSet object. This is optional only if annotation slot in the eSet x.o is defined.
x.o is an eSet/ExpressionSet. Probe ID are usually the featureNames, an attribute under the class eSet. If TRUE, conversion from probe id to gene symbol is performed automatically.
getSeedMatrix.
(1) Infer mRNA i targeted by miRNA k taking into account the hidden total expression of 1...N mRNA and miRNA k
(2) Estimate total transcription level of mRNA i
(3) Infer miRNA k "targeted" by mRNA i taking into account 1...M miRNA and mRNA i expression
(4) Repeat 1-3 until convergence
User provide roleswitch an N x M seed-match matrix containg the number of target sites for each mRNA i and miRNA k. Otherwise, getSeedMatrix will be used to retrieve seed-match matrix. The output ProMISe is one of the matrices: mRNA competition; miRNA competition; joint competition. We recommand using mRNA competition or joint competition.
getSeedMatrix
x.o <- matrix(abs(rnorm(10, mean=3)),
dimnames=list(c(1:10),"mRNA")) # mRNA expression
z.o <- matrix(abs(rnorm(4, mean=3)),
dimnames=list(c(1:4),"miRNA")) # miRNA expression
c <- matrix(rpois(40, lambda=3),nrow=nrow(x.o),
dimnames=list(c(1:10),c(1:4))) # seed match matrix
rs.pred <- roleswitch(x.o, z.o, c)
rs.pred$p.xz
Run the code above in your browser using DataLab